//
//  DataBaseManager.m
//  UserDefault
//
//  Created by akash on 3/8/16.
//  Copyright (c) 2016 evon. All rights reserved.
//

#import "DataBaseManager.h"

@implementation DataBaseManager
static sqlite3 *database = nil;
static sqlite3_stmt *statement = nil;

+ (id)sharedDatabaseManager {
    
    static DataBaseManager *dbManager;
    static dispatch_once_t once;
    
    dispatch_once(&once, ^{
        dbManager = [self new];
        [dbManager createDatabaseFile];
    });
    
    return dbManager;
}

- (NSString *)databasePath {
    NSString *pathForDocumentDir = [NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES) objectAtIndex:0];
    pathForDocumentDir = [pathForDocumentDir stringByAppendingPathComponent:@"EmployeeInfo.sqlite"];
    return pathForDocumentDir;
}

- (void)createDatabaseFile {
    
    NSString *pathForDocumentDir = [self databasePath];
    
    if ([[NSFileManager defaultManager] fileExistsAtPath:pathForDocumentDir]) {
        return;
    }
    
    NSString *path = [[NSBundle mainBundle] pathForResource:@"EmployeeInfo" ofType:@"sqlite"];
    NSLog(@"bundle path %@",path);
    
    
    NSLog(@"doc dir path %@",pathForDocumentDir);
    
    NSError *err;
    [[NSFileManager defaultManager] copyItemAtPath:path toPath:pathForDocumentDir error:&err];
    
    if (err) {
        NSLog(@"error while transferring file=> %@",err.localizedDescription);
    } else {
        NSLog(@"db file saved in documents");
    }
}


- (BOOL)saveEmployeeRecordToDB:(EmpModel*)emp {
    
    const char *dbpath = [self.databasePath UTF8String];
    
    if (sqlite3_open(dbpath, &database) == SQLITE_OK)
    {
        
        NSString *insertSQL = [NSString stringWithFormat:@"insert into Employee (Emp_Name, Emp_Address, Emp_Email, Emp_Phone) values (\"%@\",\"%@\", \"%@\", \"%@\")",[emp empName],[emp empAddress],[emp empEmail],[emp empPhoneNumber]];
        
        const char *insert_stmt = [insertSQL UTF8String];
        
        sqlite3_prepare_v2(database, insert_stmt,-1, &statement, NULL);
        
        BOOL success;
        
        if (sqlite3_step(statement) == SQLITE_DONE)
        {
            success = YES;
        }
        else {
            success = NO;
        }
        
        sqlite3_reset(statement);
        
        return success;
    }
    return NO;
}

- (NSArray*)getAllEmployees {
    
    const char *dbpath = [self.databasePath UTF8String];
    
    NSMutableArray *resultArray = [NSMutableArray new];
    
    if (sqlite3_open(dbpath, &database) == SQLITE_OK)
    {
        
        NSString *getEmployeesSQL = [NSString stringWithFormat:@"select * from Employee"];
        
        const char * get_stmt = [getEmployeesSQL UTF8String];
        
        if (sqlite3_prepare_v2(database,
                               get_stmt, -1, &statement, NULL) == SQLITE_OK)
        {
            
            while (sqlite3_step(statement) == SQLITE_ROW)
            {
                NSInteger empId = sqlite3_column_int(statement, 0);
                
                NSString *name = [[NSString alloc] initWithUTF8String:
                                  (const char *) sqlite3_column_text(statement, 1)];
                NSString *address = [[NSString alloc] initWithUTF8String:
                                     (const char *) sqlite3_column_text(statement, 2)];
                NSString *email = [[NSString alloc] initWithUTF8String:
                                   (const char *) sqlite3_column_text(statement, 3)];
                
                NSString *phone = [[NSString alloc] initWithUTF8String:
                                   (const char *) sqlite3_column_text(statement, 4)];
                
                EmpModel *model = [[EmpModel alloc] initWithName:name address:address phone:phone email:email empId:empId];
                [resultArray addObject:model];
        
            }
            
            sqlite3_reset(statement);
            
        }
        else{
            NSLog(@"Not found");
            return nil;
        }
    }
            NSLog(@"%@",resultArray);
    return resultArray;
}


@end
